#
# spec file for package python-glean
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-glean
Version:        1.18.2
Release:        bp156.3.1
Summary:        Program to write static config from config-drive
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://www.openstack.org/
Source:         https://files.pythonhosted.org/packages/source/g/glean/glean-%{version}.tar.gz
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
# The OpenStack package oslotest is only available for the primary python3 flavor on TW.
# On Leap (backports at least), the python2 package conflicts with the python3 package.
BuildRequires:  python3-oslotest >= 1.1.0.0a1
BuildRequires:  python3-python-subunit
BuildRequires:  python3-testrepository >= 0.0.18
BuildRequires:  python3-testscenarios >= 0.4
BuildRequires:  python3-testtools >= 0.9.34
# /SECTION
%python_subpackages

%description
Glean is a program intended to configure a system based on configuration
provided in a configuration drive.
Different cloud providers have different ways of providing networking and
other configuration to guest virtual-machines. Many use DHCP but others,
notably Rackspace, use configuration provided via a configuration drive.

%prep
%setup -q -n glean-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/glean-install
%python_clone -a %{buildroot}%{_bindir}/glean
%python_clone -a %{buildroot}%{_bindir}/glean.sh
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# only test the primary python3 flavor
export PYTHON=%{_bindir}/python3
python3 setup.py testr

%post
%python_install_alternative glean-install
%python_install_alternative glean
%python_install_alternative glean.sh

%postun
%python_uninstall_alternative glean-install
%python_uninstall_alternative glean
%python_uninstall_alternative glean.sh

%files %{python_files}
%doc AUTHORS ChangeLog README.rst
%license LICENSE
%python_alternative %{_bindir}/glean.sh
%python_alternative %{_bindir}/glean
%python_alternative %{_bindir}/glean-install
%{python_sitelib}/*

%changelog
* Thu Feb  4 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.18.2
  * add hosts entries and ssh keys only once
  * Do not fail if routes are missing from a network
- Changes in 1.18.1
  * Add container build jobs
  * Drop release test
  * Update functional tests
- Only test on python3: OpenStack oslotest only available there
* Thu Jun  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.18.0:
  * write one resolv config
  * Switch to Fedora 30 jobs
  * Fix a handful of bugs in config-drive processing
  * Remove trusty job
  * Move opensuse jobs to experimental for now
  * Add support for SLES
  * Do not bring up udev assigned interfaces
  * Update testing to opensuse 15
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Oct  4 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.15.0
  * Sync when writing the file
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 1.14.1
  * Enable RAs with gentoo when using dhcpv6-stateless
  * network-manager: add network-pre dependencies
  * Replace nodepool func jobs
  * Add .zuul.yaml
  * Pin sphinx
  * OpenDev Migration Patch
* Fri Apr 26 2019 pgajdos@suse.com
- version update to 1.14.0
  * Ignore Wireguard interfaces
  * Use openstackdocstheme
* Wed Jan  9 2019 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 1.13.0)
